;;; By Jimmy Bergmark
;;; Copyright (C) 2009 JTB World, All Rights Reserved
;;; Website: www.jtbworld.com
;;; E-mail: info@jtbworld.com
;;; 2009-03-17 - First release
;;; Tested on AutoCAD 2010

;;; changes the background depending on the state of OSNAPZ

; activate the reactor with the (chz) command
; remove the semicolon befor on the last row to automatically activate this upon loading this lisp
; you can load this in each drawing with acaddoc.lsp
; http://www.jtbworld.com/lisp/acaddoc.htm
: background colors can easily be changed below in the code.

(vl-load-com)
(defun chz ()
    (if    (not ct_rea)
    (setq
        ct_rea (vlr-sysvar-reactor
               nil
               '((:vlr-sysVarChanged . reactonosnapz))
           )
    )
    ) 
)

(defun reactonosnapz (event parameter)
    (if (= (car parameter) "OSNAPZ")
      (if (= (cadr parameter) T)
	(if (= (getvar "OSNAPZ") 1)
          (BGGrey)
          (BGWhite)
	)
      )
    )
)

; Set the background in model and paper space to grey
(defun BGGrey ()
  (setq disp (vla-get-display (vla-get-preferences (vlax-get-acad-object))))
  (setq drafting (vla-get-drafting (vla-get-preferences (vlax-get-acad-object))))
  (vla-put-GraphicsWinModelBackgrndColor disp 5987163)
  (vla-put-GraphicsWinLayoutBackgrndColor disp 5987163)
  (vla-put-LayoutCrosshairColor disp 16777215)
  (vla-put-ModelCrosshairColor disp 16777215)
  (vla-put-AutoTrackingVecColor disp 16777215)
  (vla-put-AutoSnapMarkerColor drafting 2)
)

; Set the background in model and paper space to white
(defun BGWhite ()
  (setq disp (vla-get-display (vla-get-preferences (vlax-get-acad-object))))
  (setq drafting (vla-get-drafting (vla-get-preferences (vlax-get-acad-object))))
  (vla-put-GraphicsWinModelBackgrndColor disp 16777215)
  (vla-put-GraphicsWinLayoutBackgrndColor disp 16777215)
  (vla-put-LayoutCrosshairColor disp 0)
  (vla-put-ModelCrosshairColor disp 0)
  (vla-put-AutoTrackingVecColor disp 0)
  (vla-put-AutoSnapMarkerColor drafting 6)
)

; Set the background in model and paper space to black
(defun BGBlack ()
  (setq disp (vla-get-display (vla-get-preferences (vlax-get-acad-object))))
  (setq drafting (vla-get-drafting (vla-get-preferences (vlax-get-acad-object))))
  (vla-put-GraphicsWinModelBackgrndColor disp 0)
  (vla-put-GraphicsWinLayoutBackgrndColor disp 0)
  (vla-put-LayoutCrosshairColor disp 16777215)
  (vla-put-ModelCrosshairColor disp 16777215)
  (vla-put-AutoTrackingVecColor disp 16777215)
  (vla-put-AutoSnapMarkerColor drafting 2)
)

; List your current color settings so you can use them to customize the code above
(defun c:ListColors ()
  (vl-load-com)
  (setq disp (vla-get-display (vla-get-preferences (vlax-get-acad-object))))
  (setq drafting (vla-get-drafting (vla-get-preferences (vlax-get-acad-object))))
  (princ "\nGraphicsWinModelBackgrndColor: ")
  (princ (vlax-variant-value (vlax-variant-change-type (vla-get-GraphicsWinModelBackgrndColor disp) vlax-vbLong)))
  (princ "\nGraphicsWinLayoutBackgrndColor: ")
  (princ (vlax-variant-value (vlax-variant-change-type (vla-get-GraphicsWinLayoutBackgrndColor disp) vlax-vbLong)))
  (princ "\nLayoutCrosshairColor: ")
  (princ (vlax-variant-value (vlax-variant-change-type (vla-get-LayoutCrosshairColor disp) vlax-vbLong)))
  (princ "\nModelCrosshairColor: ")
  (princ (vlax-variant-value (vlax-variant-change-type (vla-get-ModelCrosshairColor disp) vlax-vbLong)))
  (princ "\nAutoTrackingVecColor: ")
  (princ (vlax-variant-value (vlax-variant-change-type (vla-get-AutoTrackingVecColor disp) vlax-vbLong)))
  (princ "\nAutoSnapMarkerColor: ")
  (princ (vla-get-AutoSnapMarkerColor drafting))
  (princ)
)

;(chz)